@@ -20,7 +20,7 @@ import sys
 import stat
 from os import linesep, chmod, sep
 from os.path import expanduser, abspath, join
- 
+
 from optionstunnel import OptionsTunnel
 
 SSHOPTS = '-o NoHostAuthenticationForLocalhost=yes -o StrictHostKeyChecking=no'
@@ -54,6 +54,7 @@ class Terminal:
 
     def extrait_ordres(self, nomfichier):
         """Extrait les ordres du fichier d'ordres"""
+        # on récupère les ordres (fichiers ou entrée standard)
         try:
             if nomfichier is not None:
                 self._ordres = open(expanduser(nomfichier), 'r').readlines()
@@ -65,15 +66,17 @@ class Terminal:
         except KeyboardInterrupt:
             print _("Belier has been stopped manually by the user")
             sys.exit(1)
+        # deux passes pour étudier les ordres
         for boucle in xrange(2):
             for num in xrange(len(self._ordres)):
+                # 1ère passe : on écarte les erreurs banales
                 if boucle == 0 and self._ordres[num] != linesep:
                     if '\0' in self._ordres[num]:
                         print _("The file format is invalid \
 It may be a binary file ?")
                         sys.exit(1)
                     self._ordres[num] = self.remplace_guillemets_motdepasse(
-                                                            self._ordres[num]) 
+                                                            self._ordres[num])
                     if len(self._ordres[num].split(' ')) > 5:
                         print _("Incorrect argument number \
 on the order file line")
@@ -95,8 +98,8 @@ exceeds 64 characters")
                             sys.exit(1)
                     if self._ordres[num].split()[-1] == '-c'+ linesep or \
                         self._ordres[num].split()[-1] == '-c':
-                        break 
-
+                        break
+                # 2ème passe : on génère les scripts
                 if boucle == 1:
                     self.interprete_ordres(num)
                     self.fin_liste_ordres(num)
@@ -106,11 +109,13 @@ exceeds 64 characters")
         est_temoin = True
         est_vraiefin = False
         motdepasse = '"'
+        # on transforme les mots de passe entre guillemets en jeton
+        # on évite ainsi les caractères d'espacement gênants
         while est_temoin:
             debut = ligne.find(' "')
             if debut != -1:
                 intermediaire = ligne[debut+2:]
-                while not est_vraiefin: 
+                while not est_vraiefin:
                     if '"' in intermediaire:
                         prochain = intermediaire.find('"')
                         motdepasse = motdepasse + intermediaire[:prochain+1]
@@ -133,17 +138,23 @@ exceeds 64 characters")
 
     def fin_liste_ordres(self, num):
         """On traite la fin d'une liste d'ordres"""
-        if (self._ordres[num] == linesep and 
-			self._script[-1] != self._entetel2) or (
-                    num + 1 == len(self._ordres) and 
-				self._script[-1] != self._entetel2):
-            # remplace le dernier numero de port du tunnel
+        if (self._ordres[num] == linesep and
+            self._script[-1] != self._entetel2) or (
+                    num + 1 == len(self._ordres) and
+                self._script[-1] != self._entetel2):
+            # remplace les numéros de port du tunnel
             if self._a_tunnel:
                 if self._pdest:
-                    self._script[self._dernierssh] = self._script[
-                        self._dernierssh].replace(
-                            '-L9999:127.0.0.1:9999','-L%s:127.0.0.1:%s' % (
-                                self._pdest, self._port),1)
+                    if self._port:
+                        self._script[self._dernierssh] = self._script[
+                            self._dernierssh].replace(
+                                '-L9999:127.0.0.1:9999','-L%s:127.0.0.1:%s' % (
+                                    self._pdest, self._port),1)
+                    else:
+                        self._script[self._dernierssh] = self._script[
+                            self._dernierssh].replace(
+                                '-L9999:127.0.0.1:9999','-L%s:127.0.0.1:22' % (
+                                    self._pdest),1)
                 else:
                     if self._port:
                         self._script[self._dernierssh] = self._script[
@@ -153,18 +164,21 @@ exceeds 64 characters")
                         self._script[self._dernierssh] = self._script[
                             self._dernierssh].replace(
                                 '127.0.0.1:9999','127.0.0.1:22', 1)
+            # dernière ligne du script en fonction mode commande
             if not self._a_commande:
                 self._script.append('interact +++ return%s' % linesep)
             else:
                 self._script.append('expect eof%s' % linesep)
             resultat = abspath(join(self._destination,
                  ''.join([self._machinefinale, self._extfichier])))
+            # écriture du script
             try:
                 open(resultat, 'w').writelines(self._script)
                 chmod(resultat, stat.S_IRUSR | stat.S_IWUSR | stat.S_IXUSR )
             except IOError, message:
                 print message
                 sys.exit(1)
+            # compteur à zéro pour le prochain bloc d'ordres
             self._script = [self._entetel1, self._entetel2]
             self._est_premiereligne = True
             self._a_commande = False
@@ -176,8 +190,9 @@ exceeds 64 characters")
         ligne = self._ordres[num]
         if ligne != linesep:
             if self._a_commande:
+                # on traite le cas spécial du mode commande
                 self.traite_commande(ligne)
-            elif self._a_optstunnel: 
+            elif self._a_optstunnel:
                 # on prepare les options du tunnel
                 optstunnel = OptionsTunnel(ligne)
                 psource, pdestination = \
@@ -197,6 +212,7 @@ exceeds 64 characters")
                     self._a_optstunnel = True
                 machine = ligne.split()[0]
                 self._machinefinale = ligne.split()[0].split('@')[-1]
+                self._port = ''
                 if ':' in self._machinefinale:
                     self._machinefinale, self._port = \
 self._machinefinale.split(':')
@@ -207,6 +223,7 @@ self._machinefinale.split(':')
                     tunnelopts = ''
 
                 if self._est_premiereligne:
+                    # première connexion
                     if not self._port:
                         self._script.append('spawn ssh %s %s %s%s' % (
                             SSHOPTS, tunnelopts, machine, linesep))
@@ -216,12 +233,12 @@ self._machinefinale.split(':')
                     self._est_premiereligne = False
                 else:
                     if not self._port:
-                        self._script.append('send -- "ssh %s %s %s\\r"%s' % 
+                        self._script.append('send -- "ssh %s %s %s\\r"%s' %
                             (SSHOPTS, tunnelopts, machine, linesep))
                     else:
                         self._script.append(
                             'send -- "ssh -p %s %s %s %s\\r"%s' %
-                            (self._port, SSHOPTS, tunnelopts, machine, 
+                            (self._port, SSHOPTS, tunnelopts, machine,
                                 linesep))
                 if self._a_tunnel:
                     self._dernierssh = len(self._script) - 1
@@ -261,7 +278,7 @@ self._machinefinale.split(':')
 
     def traite_commande(self, ligne):
         """Traite la commande contenue dans la ligne courante"""
-        self._script.append('send -- "%s\\r"%s' 
+        self._script.append('send -- "%s\\r"%s'
             % (ligne.rstrip(linesep), linesep))
         self.prepare_prompt()
 
@@ -275,15 +292,13 @@ self._machinefinale.split(':')
         self.prepare_prompt()
 
     def prepare_prompt(self):
-        """Prépare le prompt en fonction de l'identité de l'utilisateur""" 
-        self._script.append('expect -re  "(%s|#|\\\\$) $"%s' % ('%', linesep)) 
-        
+        """Prépare le prompt en fonction de l'identité de l'utilisateur"""
+        self._script.append('expect -re  "(%s|#|\\\\$) $"%s' % ('%', linesep))
 
     def envoie_motdepasse_ssh(self, motdepasse):
         """Envoie le mot de passe lors d'une connexion ssh"""
         if motdepasse in self._jetons:
             motdepasse = self._jetons[motdepasse]
-        self._script.append('expect -re {@[^\\n]*:}%s' % linesep) 
+        self._script.append('expect -re {@[^\\n]*:}%s' % linesep)
         self._script.append('send -- "%s\\r"%s' % (motdepasse, linesep))
         self.prepare_prompt()
-        
